/*
 * @author Stefan Hepp
 * @date 12.7.2005
 * @version $Id: AdvancedViewExample.java,v 1.6 2009-12-16 16:12:02 herbert Exp $
 */

package com.gentics.portalnode.sdk;

import java.io.IOException;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import com.gentics.api.portalnode.event.ActionEvent;
import com.gentics.api.portalnode.event.EventRequest;
import com.gentics.api.portalnode.event.EventResponse;
import com.gentics.api.portalnode.plugin.GenticsPlugin;
import com.gentics.api.portalnode.plugin.ViewPlugin;
import com.gentics.api.portalnode.portlet.AbstractGenticsPortlet;
import com.gentics.api.portalnode.portlet.GenticsPortletContext;
import com.gentics.api.portalnode.templateengine.PrivateKeyException;
import com.gentics.api.portalnode.templateengine.TemplateNotFoundException;
import com.gentics.api.portalnode.templateengine.TemplateProcessor;

/**
 * Simple module to create a view and display it.
 */
public class AdvancedViewExample extends AbstractGenticsPortlet {
    private static final String SESSION_OUTPUT = "com.gentics.AdvancedViewExample.output";


    public AdvancedViewExample(String moduleId) throws PortletException {
        super(moduleId);
    }

    protected void onLoad() {
        super.onLoad();

        // create a new viewplugin
        GenticsPlugin plugin = getGenticsPortletContext().createPlugin(
                "ViewPlugin", "viewplugin", getPortletConfig());

        // register the plugin
        if (plugin instanceof ViewPlugin) {
            registerPlugin("viewplugin", plugin);
        }
    }

    public void processAction(ActionRequest request, ActionResponse response) throws PortletException, IOException {
        if ("back".equals(request.getParameter("action"))) {
            ((ViewPlugin) getPlugin("viewplugin")).setActiveView("demo");
            request.getPortletSession().setAttribute(SESSION_OUTPUT, "demo");
        }
    }

    protected void doView(RenderRequest renderRequest, RenderResponse renderResponse)
            throws PortletException, IOException {

        Object output = renderRequest.getPortletSession().getAttribute(SESSION_OUTPUT);

        if (output != null && "view".equals(output.toString())) {

            // render the output using the templateprocessor
            GenticsPortletContext ctx = getGenticsPortletContext();
            TemplateProcessor templateProcessor  = ctx.getTemplateProcessor(this, getPortletConfig());

            try {

                // create an actionurl which clears the history
                PortletURL actionURL = renderResponse.createActionURL();
                actionURL.setParameter("action", "back");

                // get the templateprocessor and add the variables to it
                templateProcessor.put("data", ((ViewPlugin) getPlugin("viewplugin")).getViewDataAsMap("demo"));
                templateProcessor.put("backlink", actionURL);

                // render the main-template
                renderResponse.getWriter().print(templateProcessor.getOutput("output", this));

            } catch (PrivateKeyException e) {
                logger.error(e);
            } catch (TemplateNotFoundException e) {
                logger.error(e);
            } finally {
                // return the template processor
                returnTemplateProcessor(templateProcessor);
            }

        } else {
            // render the viewplugin directly to the output
            renderResponse.getWriter().print(
                    renderPlugin("viewplugin", renderRequest, renderResponse));
        }
    }

    public void onPluginEvent(EventRequest eventRequest, EventResponse eventResponse) {
        super.onPluginEvent(eventRequest, eventResponse);

        ActionEvent event = eventRequest.getEvent().getEmbeddedEvent();

        if ("view".equals(event.getActionCommand())) {
            ((ViewPlugin) getPlugin("viewplugin")).setActiveView("view");
            eventRequest.getPortletSession().setAttribute(SESSION_OUTPUT, "view");
        }
    }
}
